@@ -7,7 +7,7 @@ import threading
 
 import requests
 
-__version__ = '1.0.4a'
+__version__ = '1.3b'
 
 class Event(object):
     def __init__(self, connection):
@@ -16,7 +16,7 @@ class Event(object):
     def parse(self, connection):
         returned = {}
         if connection["event"] == "join":
-            connection["joinData"] = json.loads(connection["joinData"])
+            connection["data"] = json.loads(connection["data"])
         elif connection["event"] != "disableReconnect":
             connection["data"] = json.loads(connection["data"])
         if connection["event"] == "kick":
@@ -53,7 +53,7 @@ class Event(object):
             returned["time"] = None
             returned["madechatmod"] = False
         elif connection["event"] == "join":
-            returned["user"] = connection["joinData"]["attrs"]["name"]
+            returned["user"] = connection["data"]["attrs"]["name"]
             returned["text"] = None
             returned["status"] = "here"
             returned["time"] = None
@@ -145,18 +145,18 @@ class Client(object):
         self.xhr = self.__initialize(self.settings)
         self.priv_dict = {}
 
-    def __login(self, username, password):
+def login(username, password):
         login_data = {
             'action': 'login',
             'lgname': username,
             'lgpassword': password,
             'format':'json'}
         data = urllib.urlencode(login_data)
-        response = self.session.post(self.wiki + "/api.php",data=login_data)
+        response = session.post(self.wiki + "/api.php",data=login_data)
         content = json.loads(response.content)
         login_data['lgtoken'] = content['login']['token']
         data = urllib.urlencode(login_data)
-        response = self.session.post(self.wiki + "/api.php",data=login_data)
+        response = session.post(self.wiki + "/api.php",data=login_data)
         content = json.loads(response.content)
         if content['login']['result'] != 'Success':
             print 'Couldn\'t log in: Quitting.'
@@ -167,7 +167,6 @@ class Client(object):
         for karg in kwargs:
             request[karg] = kwargs[karg]
         response = self.session.get(self.wiki + "/wikia.php",params=request)
-        print response.content
         content = json.loads(response.content)
         return content
 
@@ -197,9 +196,6 @@ class Client(object):
 
     def __send(self, settings, xhr, message):
         xhr_polling = self.__get_code(xhr)
-        print "http://" + settings["host"] + ":" + settings["port"] + "/socket.io/1/xhr-polling/" + xhr_polling + "?name=" \
-            + self.username + "&key=" \
-            + settings['chatkey'] + "&roomId=" + str(settings['room']) + "&t=" + self.__timestamp()
         extras =  json.dumps({'attrs': {'msgType': 'chat', 'text': message}})
         data = self.session.post("http://" + settings["host"] + ":" + settings["port"] + "/socket.io/1/xhr-polling/" + xhr_polling + "?name=" +
             self.username + "&key=" + 
@@ -281,7 +277,6 @@ class Client(object):
     def __private_message_id(self, user):
         data = self.session.post(self.wiki + "/index.php?action=ajax&rs=ChatAjax&method=getPrivateRoomId&users=[\"" +
                                     user + "\",\"" + self.username + "\"]")
-        print data.content
         content = json.loads(data.content)
         roomid = content['id']
         return roomid
